@@ -1,3 +1,4 @@
+use holochain_types::db_cache::error::DbCacheError;
 use thiserror::Error;
 
 use crate::query::StateQueryError;
@@ -10,6 +11,8 @@ pub enum StateMutationError {
     #[error(transparent)]
     DatabaseError(#[from] holochain_sqlite::error::DatabaseError),
     #[error(transparent)]
+    DbCacheError(#[from] DbCacheError),
+    #[error(transparent)]
     DhtOpError(#[from] holochain_types::dht_op::error::DhtOpError),
     #[error(transparent)]
     StateQueryError(#[from] StateQueryError),
